@@ -1,4 +1,4 @@
-# Copyright (c) 2016 - 2023, Adrian Dusa
+# Copyright (c) 2016 - 2024, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -9,13 +9,14 @@
 #     * Redistributions in binary form must reproduce the above copyright
 #       notice, this list of conditions and the following disclaimer in the
 #       documentation and/or other materials provided with the distribution.
-#     * The names of its contributors may NOT be used to endorse or promote products
-#       derived from this software without specific prior written permission.
+#     * The names of its contributors may NOT be used to endorse or promote
+#       products derived from this software without specific prior written
+#       permission.
 # 
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-# DISCLAIMED. IN NO EVENT SHALL ADRIAN DUSA BE LIABLE FOR ANY
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL ADRIAN DUSA BE LIABLE FOR ANY
 # DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 # (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 # LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
@@ -29,7 +30,7 @@
     max.comb = 0, use.labels = FALSE, method = "CCubes", ...
 ) {
     metacall <- match.call()
-    dots <- substitute(list(...))
+    dots <- as.list(substitute(list(...)))[-1]
     if (isTRUE(dots$categorical)) { 
         use.labels <- TRUE
         dots$categorical <- NULL
@@ -79,12 +80,17 @@
     else {
         nms <- colnames(input)
     }
-    if (length(dots) > 1) {
-        for (i in seq(2, length(dots))) {
-            dots[[i]] <- admisc::recreate(dots[[i]], nms)
+    if (length(dots) > 0) {
+        for (i in seq(length(dots))) {
+            tc <- admisc::tryCatchWEM(
+                ieval <- eval(dots[[i]])
+            )
+            if (!is.null(tc$error)) {
+                ieval <- admisc::recreate(dots[[i]], nms)
+            }
+            dots[[i]] <- ieval
         }
     }
-    dots <- eval(dots)
     back.args <- c(
         "outcome", "conditions", "n.cut", "incl.cut", "complete", "show.cases",
         "sort.by" = "", "use.letters", "inf.test", "rowdom", "direxp", "neg.out",
@@ -445,10 +451,10 @@
     else {
         if (use.letters) {
             mtrxlines <- makeChart(
-                primes = rownames(p.sol$reduced$expressions), 
-                configs = tt.rows, 
-                snames = LETTERS[seq(length(conditions))], 
-                mv = mv, 
+                primes = rownames(p.sol$reduced$expressions),
+                configs = tt.rows,
+                snames = LETTERS[seq(length(conditions))],
+                mv = mv,
                 noflevels = noflevels
             )
         }
